==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/filetemplates/kdevfiletemplates.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-class
Exec=blubb
Comment=Manages templates for source files
Comment[bs]=Upravlja predlošcima za izvorne datoteke
Comment[ca]=Gestiona plantilles de fitxers de codi font
Comment[ca@valencia]=Gestiona plantilles de fitxers de codi font
Comment[da]=Håndterer skabeloner for kildefiler
Comment[de]=Verwaltung von Vorlagen für Quelltextdateien
Comment[el]=Διαχειρίζεται templates για πηγαία αρχεία
Comment[es]=Gestiona plantillas para archivos de código fuente
Comment[et]=Lähtekoodi failide mallide haldamine
Comment[fi]=Hallitsee lähdekooditiedostojen malleja
Comment[fr]=Gère les modèles pour les fichiers source
Comment[gl]=Xestiona modelos para os ficheiros de fonte
Comment[hu]=Sablonokat kezel a forrásfájlokhoz
Comment[it]=Gestisce i modelli per i file sorgente
Comment[kk]=Бастапқы коды файл үлгілерді басқару
Comment[nb]=Håndterer maler for kildefiler
Comment[nl]=Beheert sjablonen voor broncodebestanden
Comment[pl]=Zarządza szablonami dla plików źródłowych
Comment[pt]=Gere os modelos dos ficheiros de código
Comment[pt_BR]=Gerencia os modelos dos arquivos de código
Comment[ru]=Управляет шаблонами файлов исходного кода
Comment[sk]=Spravuje šablóny pre zdrojové súbory
Comment[sl]=Upravlja predloge za datoteke z izvorno kodo
Comment[sv]=Hanterar mallar för källkodsfiler
Comment[tr]=Kaynak dosyaları için şablonları yönetir
Comment[uk]=Керування шаблонами для початкових файлів коду
Comment[x-test]=xxManages templates for source filesxx
Comment[zh_CN]=管理源文件的模板
Comment[zh_TW]=管理源碼檔的樣本
Name=File Templates Configuration
Name[bs]=Konfiguracija predložaka datoteka
Name[ca]=Configuració de plantilles de fitxers
Name[ca@valencia]=Configuració de plantilles de fitxers
Name[da]=Konfiguration af filskabeloner
Name[de]=Einrichtung der Dateivorlagen
Name[el]=Διαμόρφωση αρχείων templates
Name[es]=Configuración de las plantillas de archivos
Name[et]=Failimallide seadistamine
Name[fi]=Tiedostomallien asetukset
Name[fr]=Configuration des modèles de fichiers
Name[gl]=Configuración dos modelos de ficheiros
Name[hu]=Fájl sablonok beállítása
Name[it]=Configurazione dei file dei modelli
Name[kk]=Файл үлгілерді баптау
Name[nb]=Oppsett av fil-maler
Name[nl]=Configuratie van sjabloonbestanden
Name[pl]=Konfiguracja szablonów plików
Name[pt]=Configuração dos Modelos de Ficheiros
Name[pt_BR]=Configuração dos modelos de arquivos
Name[ru]=Настройка шаблонов файлов
Name[sk]=Nastavenie šablón súborov
Name[sl]=Nastavitev predlog dokumentov
Name[sv]=Inställning av filmallar
Name[tr]=Dosya Şablon Yapılandırması
Name[uk]=Налаштовування шаблонів файлів
Name[x-test]=xxFile Templates Configurationxx
Name[zh_CN]=文件模板配置
Name[zh_TW]=檔案樣本設定
GenericName=Manages templates for source files
GenericName[bs]=Upravljanje predlošcima za izvorne datoteke
GenericName[ca]=Gestiona plantilles de fitxers de codi font
GenericName[ca@valencia]=Gestiona plantilles de fitxers de codi font
GenericName[da]=Håndterer skabeloner for kildefiler
GenericName[de]=Verwaltung von Vorlagen für Quelltextdateien
GenericName[el]=Διαχειρίζεται templates για πηγαία αρχεία
GenericName[es]=Gestiona plantillas para archivos de código fuente
GenericName[et]=Lähtekoodi failide mallide haldamine
GenericName[fi]=Hallitsee lähdekooditiedostojen malleja
GenericName[fr]=Gère les modèles pour les fichiers source
GenericName[gl]=Xestiona modelos para os ficheiros de fonte
GenericName[hu]=Sablonokat kezel a forrásfájlokhoz
GenericName[it]=Gestisce i modelli per i file sorgente
GenericName[kk]=Бастапқы коды файл үлгілерді басқару
GenericName[nb]=Håndterer maler for kildefiler
GenericName[nl]=Beheert sjablonen voor broncodebestanden
GenericName[pl]=Zarządza szablonami dla plików źródłowych
GenericName[pt]=Gere os modelos dos ficheiros de código
GenericName[pt_BR]=Gerencia os modelos dos arquivos de código
GenericName[ru]=Управляет шаблонами файлов исходного кода
GenericName[sk]=Spravuje šablóny pre zdrojové súbory
GenericName[sl]=Upravlja predloge za datoteke z izvorno kodo
GenericName[sv]=Hanterar mallar för källkodsfiler
GenericName[tr]=Kaynak dosyaları için şablonları yönetir
GenericName[uk]=Керування шаблонами для початкових файлів коду
GenericName[x-test]=xxManages templates for source filesxx
GenericName[zh_CN]=管理源文件的模板
GenericName[zh_TW]=管理源碼檔的樣本
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevfiletemplates
X-KDE-PluginInfo-Name=kdevfiletemplates
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.ITemplateProvider
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Mode=GUI

==> kdevplatform-1.7.1.tar.xz: kdevplatform-1.7.1/plugins/filetemplates/kdevfiletemplates.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-class
Exec=blubb
Comment=Manages templates for source files
Comment[bs]=Upravlja predlošcima za izvorne datoteke
Comment[ca]=Gestiona plantilles de fitxers de codi font
Comment[ca@valencia]=Gestiona plantilles de fitxers de codi font
Comment[da]=Håndterer skabeloner for kildekodefiler
Comment[de]=Verwaltung von Vorlagen für Quelltextdateien
Comment[el]=Διαχειρίζεται πρότυπα για πηγαία αρχεία
Comment[en_GB]=Manages templates for source files
Comment[es]=Gestiona plantillas para archivos de código fuente
Comment[et]=Lähtekoodi failide mallide haldamine
Comment[fi]=Hallitsee lähdekooditiedostojen malleja
Comment[fr]=Gère les modèles pour les fichiers source
Comment[gl]=Xestiona modelos para os ficheiros de fonte
Comment[hu]=Sablonokat kezel a forrásfájlokhoz
Comment[it]=Gestisce i modelli per i file sorgente
Comment[kk]=Бастапқы коды файл үлгілерді басқару
Comment[nb]=Håndterer maler for kildefiler
Comment[nl]=Beheert sjablonen voor broncodebestanden
Comment[pl]=Zarządza szablonami dla plików źródłowych
Comment[pt]=Gere os modelos dos ficheiros de código
Comment[pt_BR]=Gerencia os modelos dos arquivos de código
Comment[ru]=Управляет шаблонами файлов исходного кода
Comment[sk]=Spravuje šablóny pre zdrojové súbory
Comment[sl]=Upravlja predloge za datoteke z izvorno kodo
Comment[sv]=Hanterar mallar för källkodsfiler
Comment[tr]=Kaynak dosyaları için şablonları yönetir
Comment[uk]=Керування шаблонами для початкових файлів коду
Comment[x-test]=xxManages templates for source filesxx
Comment[zh_CN]=管理源文件的模板
Comment[zh_TW]=管理源碼檔的樣本
Name=File Templates Configuration
Name[bs]=Konfiguracija predložaka datoteka
Name[ca]=Configuració de plantilles de fitxers
Name[ca@valencia]=Configuració de plantilles de fitxers
Name[da]=Konfiguration af filskabeloner
Name[de]=Einrichtung der Dateivorlagen
Name[el]=Διαμόρφωση προτύπων αρχείων
Name[en_GB]=File Templates Configuration
Name[es]=Configuración de las plantillas de archivos
Name[et]=Failimallide seadistamine
Name[fi]=Tiedostomallien asetukset
Name[fr]=Configuration des modèles de fichiers
Name[gl]=Configuración dos modelos de ficheiros
Name[hu]=Fájl sablonok beállítása
Name[it]=Configurazione dei file dei modelli
Name[kk]=Файл үлгілерді баптау
Name[nb]=Oppsett av fil-maler
Name[nl]=Configuratie van sjabloonbestanden
Name[pl]=Ustawienia szablonów plików
Name[pt]=Configuração dos Modelos de Ficheiros
Name[pt_BR]=Configuração dos modelos de arquivos
Name[ru]=Настройка шаблонов файлов
Name[sk]=Nastavenie šablón súborov
Name[sl]=Nastavitev predlog dokumentov
Name[sv]=Inställning av filmallar
Name[tr]=Dosya Şablon Yapılandırması
Name[uk]=Налаштовування шаблонів файлів
Name[x-test]=xxFile Templates Configurationxx
Name[zh_CN]=文件模板配置
Name[zh_TW]=檔案樣本設定
GenericName=Manages templates for source files
GenericName[bs]=Upravljanje predlošcima za izvorne datoteke
GenericName[ca]=Gestiona plantilles de fitxers de codi font
GenericName[ca@valencia]=Gestiona plantilles de fitxers de codi font
GenericName[da]=Håndterer skabeloner for kildekodefiler
GenericName[de]=Verwaltung von Vorlagen für Quelltextdateien
GenericName[el]=Διαχειρίζεται πρότυπα για πηγαία αρχεία
GenericName[en_GB]=Manages templates for source files
GenericName[es]=Gestiona plantillas para archivos de código fuente
GenericName[et]=Lähtekoodi failide mallide haldamine
GenericName[fi]=Hallitsee lähdekooditiedostojen malleja
GenericName[fr]=Gère les modèles pour les fichiers source
GenericName[gl]=Xestiona modelos para os ficheiros de fonte
GenericName[hu]=Sablonokat kezel a forrásfájlokhoz
GenericName[it]=Gestisce i modelli per i file sorgente
GenericName[kk]=Бастапқы коды файл үлгілерді басқару
GenericName[nb]=Håndterer maler for kildefiler
GenericName[nl]=Beheert sjablonen voor broncodebestanden
GenericName[pl]=Zarządza szablonami dla plików źródłowych
GenericName[pt]=Gere os modelos dos ficheiros de código
GenericName[pt_BR]=Gerencia os modelos dos arquivos de código
GenericName[ru]=Управляет шаблонами файлов исходного кода
GenericName[sk]=Spravuje šablóny pre zdrojové súbory
GenericName[sl]=Upravlja predloge za datoteke z izvorno kodo
GenericName[sv]=Hanterar mallar för källkodsfiler
GenericName[tr]=Kaynak dosyaları için şablonları yönetir
GenericName[uk]=Керування шаблонами для початкових файлів коду
GenericName[x-test]=xxManages templates for source filesxx
GenericName[zh_CN]=管理源文件的模板
GenericName[zh_TW]=管理源碼檔的樣本
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevfiletemplates
X-KDE-PluginInfo-Name=kdevfiletemplates
X-KDE-PluginInfo-Author=Alexander Dymo
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Interfaces=org.kdevelop.ITemplateProvider
X-KDevelop-Category=Global
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Mode=GUI
